Cleanup/wg init (#260)
* remove wg_init and wg_finalize from functional tests
* Remove wg_init and wg_finalize from examples
* deprecate wg_init/finalize
* Updated docs
* Typo in documentation
---------
Co-authored-by: Yiltan <yiltan@amd.com>
[ROCm/rocshmem commit: 6e7277b544]
This commit is contained in:
committed by
GitHub
parent
192c549d40
commit
8837414042
@@ -37,7 +37,6 @@ __global__ void PingAllTest(int loop, int skip, long long int *start_time,
|
||||
__shared__ rocshmem_ctx_t ctx;
|
||||
int wg_id = get_flat_grid_id();
|
||||
|
||||
rocshmem_wg_init();
|
||||
rocshmem_wg_ctx_create(ctx_type, &ctx);
|
||||
|
||||
int pe = rocshmem_ctx_my_pe(ctx);
|
||||
@@ -64,7 +63,6 @@ __global__ void PingAllTest(int loop, int skip, long long int *start_time,
|
||||
rocshmem_ctx_quiet(ctx);
|
||||
}
|
||||
rocshmem_wg_ctx_destroy(&ctx);
|
||||
rocshmem_wg_finalize();
|
||||
}
|
||||
|
||||
/******************************************************************************
|
||||
|
||||
Reference in New Issue
Block a user